<?php
/**
 * Collections of functions.
 *
 * @since 1.0.0
 * @package BlockArt
 */

/**
 * Wrapper for _doing_it_wrong.
 *
 * @since 1.0.0
 * @param string $function Function used.
 * @param string $message  Message to log.
 * @param string $version  Version the message was added in.
 */
function blockart_doing_it_wrong( $function, $message, $version ) {

	// phpcs:disable
	$message .= ' Backtrace: ' . wp_debug_backtrace_summary();

	if ( function_exists( 'is_ajax' ) && is_ajax() ) {
		do_action( 'doing_it_wrong_run', $function, $message, $version );

		error_log( "{$function} was called incorrectly. {$message}. This message was added in version {$version}." );
	} else {
		_doing_it_wrong( $function, $message, $version );
	}
	// phpcs:enable
}

function blockart_widget_content( $content ) {

	$widget_blocks = get_option( 'widget_block' );

	if ( empty( $widget_blocks ) ) {
		return $content;
	}

	foreach ( (array) $widget_blocks as $block ) {
		if (
			isset( $block['content'] ) &&
			false !== strpos( $block['content'], 'blockart/' )
		) {
			$content .= $block['content'];
		}
	}

	return $content;
}
add_filter( 'blockart_block_content', 'blockart_widget_content' );
